import * as Schema from "./types";
import { Address, AccountIndex, EthereumSigner, EthereumProvider, Connection, ConnectionConfig, ConnectionConfigs } from "./Connection";
import { Client, Plugin, PluginManifest, PluginModules, PluginFactory } from "@web3api/core-js";
export { Address, AccountIndex, EthereumSigner, EthereumProvider, ConnectionConfig, ConnectionConfigs, };
export interface EthereumConfig {
    networks: ConnectionConfigs;
    defaultNetwork?: string;
}
export declare class EthereumPlugin extends Plugin {
    private _connections;
    private _defaultNetwork;
    constructor(config: EthereumConfig);
    static manifest(): PluginManifest;
    getModules(_client: Client): PluginModules;
    callContractMethod(input: Schema.Input_callContractMethod): Promise<Schema.TxResponse>;
    callContractMethodAndWait(input: Schema.Input_callContractMethodAndWait): Promise<Schema.TxReceipt>;
    sendTransaction(input: Schema.Input_sendTransaction): Promise<Schema.TxResponse>;
    sendTransactionAndWait(input: Schema.Input_sendTransactionAndWait): Promise<Schema.TxReceipt>;
    deployContract(input: Schema.Input_deployContract): Promise<string>;
    signMessage(input: Schema.Input_signMessage): Promise<string>;
    sendRPC(input: Schema.Input_sendRPC): Promise<string>;
    callContractView(input: Schema.Input_callContractView): Promise<string>;
    callContractStatic(input: Schema.Input_callContractStatic): Promise<Schema.StaticTxResult>;
    encodeParams(input: Schema.Input_encodeParams): string;
    getSignerAddress(input: Schema.Input_getSignerAddress): Promise<string>;
    getSignerBalance(input: Schema.Input_getSignerBalance): Promise<string>;
    getSignerTransactionCount(input: Schema.Input_getSignerTransactionCount): Promise<string>;
    getGasPrice(input: Schema.Input_getGasPrice): Promise<string>;
    estimateTransactionGas(input: Schema.Input_estimateTransactionGas): Promise<string>;
    estimateContractCallGas(input: Schema.Input_estimateContractCallGas): Promise<string>;
    checkAddress(input: Schema.Input_checkAddress): boolean;
    toWei(input: Schema.Input_toWei): string;
    toEth(input: Schema.Input_toEth): string;
    waitForEvent(input: Schema.Input_waitForEvent): Promise<Schema.EventNotification>;
    awaitTransaction(input: Schema.Input_awaitTransaction): Promise<Schema.TxReceipt>;
    getConnection(connection?: Schema.Connection): Promise<Connection>;
    parseArgs(args?: string[]): unknown[];
    private _callContractMethod;
}
export declare const ethereumPlugin: PluginFactory<EthereumConfig>;
export declare const plugin: PluginFactory<EthereumConfig>;
